@@ -448,8 +448,7 @@ module ActiveRecord
         @available.num_waiting
       end
 
-      # Return connection pool's usage statistic
-      # Example:
+      # Returns the connection pool's usage statistic.
       #
       #    ActiveRecord::Base.connection_pool.stat # => { size: 15, connections: 1, busy: 1, dead: 0, idle: 0, waiting: 0, checkout_timeout: 5 }
       def stat
@@ -653,9 +652,14 @@ module ActiveRecord
         alias_method :release, :remove_connection_from_thread_cache
 
         def new_connection
-          Base.public_send(db_config.adapter_method, db_config.configuration_hash).tap do |conn|
+          conn = Base.public_send(db_config.adapter_method, db_config.configuration_hash)
+          begin
             conn.check_version
+          rescue
+            conn.disconnect!
+            raise
           end
+          conn
         end
 
         # If the pool is not at a <tt>@size</tt> limit, establish new connection. Connecting
